Attribute VB_Name = "Callbacks"
'Hello World for multimon, VB version
'displays information about all monitors and says hello on each one
'
'This source code may be freely distributed as long as it is not being modified.
'You may freely use this source code in your own applications, commercial or not.
'copyright 1999 by Realtime Soft, www.realtimesoft.com
'send bug reports to multimon@realtimesoft.com.
'
'THE SOURCE CODE IS PROVIDED "AS-IS" AND WITHOUT WARRANTY OF ANY KIND, EXPRESS, IMPLIED
'OR OTHERWISE, INCLUDING WITHOUT LIMITATION, ANY WARRANTY OF MERCHANTABILITY OR FITNESS
'FOR A PARTICULAR PURPOSE.
'
'IN NO EVENT SHALL REALTIME SOFT BE LIABLE FOR ANY SPECIAL, INCIDENTAL, INDIRECT OR
'CONSEQUENTIAL DAMAGES OF ANY KIND, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
'DATA OR PROFITS, WHETHER OR NOT ADVISED OF THE POSSIBILITY OF DAMAGE, AND ON ANY THEORY
'OF LIABILITY, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS
'SOURCE CODE.

Public infoBox 'global reference to the list box
Public helloForms 'collection which holds references to all the displayed Hello forms

Public Const CCHFORMNAME = 32
Public Const ENUM_CURRENT_SETTINGS = &HFFFFFFFF

Public Type DEVMODE
        dmDeviceName As String * CCHDEVICENAME
        dmSpecVersion As Integer
        dmDriverVersion As Integer
        dmSize As Integer
        dmDriverExtra As Integer
        dmFields As Long
        dmOrientation As Integer
        dmPaperSize As Integer
        dmPaperLength As Integer
        dmPaperWidth As Integer
        dmScale As Integer
        dmCopies As Integer
        dmDefaultSource As Integer
        dmPrintQuality As Integer
        dmColor As Integer
        dmDuplex As Integer
        dmYResolution As Integer
        dmTTOption As Integer
        dmCollate As Integer
        dmFormName As String * CCHFORMNAME
        dmUnusedPadding As Integer
        dmBitsPerPel As Long
        dmPelsWidth As Long
        dmPelsHeight As Long
        dmDisplayFlags As Long
        dmDisplayFrequency As Long
End Type

Public Declare Function EnumDisplaySettings Lib "user32" Alias "EnumDisplaySettingsA" _
    (ByVal lpszDeviceName As String, ByVal iModeNum As Long, lpDevMode As DEVMODE) As Long
Public Declare Function lstrlen Lib "kernel32" Alias "lstrlenA" (ByVal lpString As String) As Long

'Code to test if EnumDisplaySettings is available
Private Declare Function LoadLibrary Lib "kernel32" _
  Alias "LoadLibraryA" (ByVal lpLibFileName As String) As Long

Private Declare Function GetProcAddress Lib "kernel32" _
  (ByVal hModule As Long, ByVal lpProcName As String) As Long

Private Declare Function FreeLibrary Lib "kernel32" _
  (ByVal hLibModule As Long) As Long
    
    
'callback. gets called once for each monitor, adds information about the monitor
'to the list box
Public Function MonitorInfoEnum(ByVal hm As Long, ByVal dcMon As Long, pRc As RECT, _
    lParam As Long) As Long
    'get information about this monitor, including its device name (\\.\DISPLAYx)
    Dim mi As MONITORINFOEX
    mi.cbSize = Len(mi)
    GetMonitorInfo hm, mi

    'get resolution, colordepth and refresh rate of the monitor
    Dim dm As DEVMODE
    dm.dmSize = Len(dm)
    EnumDisplaySettings mi.szDevice, ENUM_CURRENT_SETTINGS, dm
    
    'add information to list box
    Dim str As String
    str = "Monitor " & Mid(mi.szDevice, 12, lstrlen(mi.szDevice) - 11)
    If mi.dwFlags And MONITORINFOF_PRIMARY Then str = str & " (primary)"
    str = str & ":"
    infoBox.AddItem str
    
    'add device name
    infoBox.AddItem "  Device name: " & mi.szDevice
    
    'add top-left and bottom-right coordinates of monitor and work area
    'work area is the monitor excluding tool bars (such as the task bar)
    infoBox.AddItem "  " & mi.rcMonitor.Left & "," & mi.rcMonitor.Top & " - " & _
        mi.rcMonitor.Right & "," & mi.rcMonitor.Bottom & ". Work area: " & _
        mi.rcWork.Left & "," & mi.rcWork.Top & " - " & mi.rcWork.Right & "," & _
        mi.rcWork.Bottom
        
    'add monitor resolution, colordepth and refresh rate
    Dim refreshRate As String
    If dm.dmDisplayFrequency = 0 Or dm.dmDisplayFrequency = 1 Then
        refreshRate = "default"
    Else
        refreshRate = dm.dmDisplayFrequency & " Hz"
    End If
    infoBox.AddItem "  " & dm.dmPelsWidth & "x" & dm.dmPelsHeight & ", " & _
        dm.dmBitsPerPel & "-bit color, " & refreshRate & " refresh rate"
    
    infoBox.AddItem ""
    
    MonitorInfoEnum = True
End Function
'callback. gets called once for each monitor, creates a Hello form for each monitor
'and adds a reference to it to the helloForms collection
Public Function MonitorHelloEnum(ByVal hm As Long, ByVal dcMon As Long, pRc As RECT, _
    lParam As Long) As Long
    Dim mi As MONITORINFOEX
    mi.cbSize = Len(mi)
    GetMonitorInfo hm, mi
    
    Dim width As Long, height As Long
    width = mi.rcMonitor.Right - mi.rcMonitor.Left
    height = mi.rcMonitor.Bottom - mi.rcMonitor.Top
    
    'create a centered 320x240 form on each monitor. this code doesn't center the form
    'exactly, seems like some problem with the units/scale mode used. if you know how
    'to fix this, please let me know at multimon@realtimesoft.com
    Dim hf As New HelloForm
    hf.Left = (mi.rcMonitor.Left + (width - 320) / 2) * Screen.TwipsPerPixelX
    hf.Top = (mi.rcMonitor.Top + (height - 240) / 2) * Screen.TwipsPerPixelY
    hf.HelloText.Caption = "Hello, monitor " & Mid(mi.szDevice, 12, _
        lstrlen(mi.szDevice) - 11) & "!"
    hf.Show vbModeless, Forms(0)
    
    helloForms.Add hf
    
    MonitorHelloEnum = True
End Function
Public Function APIFunctionPresent(ByVal FunctionName _
   As String, ByVal DllName As String) As Boolean

    Dim lHandle As Long
    Dim lAddr  As Long

    lHandle = LoadLibrary(DllName)
    If lHandle <> 0 Then
        lAddr = GetProcAddress(lHandle, FunctionName)
        FreeLibrary lHandle
    End If
    
    APIFunctionPresent = (lAddr <> 0)

End Function
